@@ -1,18 +1,9 @@
-# -*- coding: utf-8 -*-
-#-------------------------------------------------------------------------------
-# Copyright (c) 2012 Michael Hull, Michael Vella
-# All rights reserved.
-# 
-# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
-# 
-#  - Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-#  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-# 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#-------------------------------------------------------------------------------
-
 import numpy as np
 from nml.nml import parse as nmlparse
+from neuroml import arraymorph
+import neuroml
+from jsonpickle import decode as json_decode
+import neuroml
 
 class NeuroMLLoader(object):
 
@@ -34,6 +25,9 @@ class NeuroMLLoader(object):
 
 
 class SWCLoader(object):
+    """
+    WARNING: Class defunct
+    """
     
     @classmethod
     def load_swc_single(cls,  src, name=None):
@@ -77,5 +71,84 @@ class SWCLoader(object):
 
         #This needs to become an "Optimized Morphology" of some kind
         return Backend(vertices=vertices, 
-                              connectivity=connection_indices, 
-                              name=name )
+                       connectivity=connection_indices, 
+                       name=name )
+
+class JSONLoader(object):
+
+    @classmethod
+    def load(cls,file):
+        if isinstance(file,str):
+            fileh = open(file,'r')
+        else:
+            fileh = file
+
+        json_string = fileh.read()
+        unpickled = json_decode(json_string)
+        return unpickled
+        
+    @classmethod
+    def load_from_mongodb(cls,
+                          db,
+                          id,
+                          host=None,
+                          port=None):
+        
+        from pymongo import MongoClient
+        import simplejson as json
+        
+        if host == None:
+            host = 'localhost'
+        if port == None:
+            port = 27017
+
+        client = MongoClient(host,port)
+
+        db = client[db]
+
+        collection = db[id]
+
+        doc = collection.find_one()
+
+        del doc['_id']         
+
+        doc = json.dumps(doc)
+
+        document = json_decode(doc)
+
+        return document
+        
+class ArrayMorphLoader(object):
+
+    @classmethod
+    def __extract_morphology(cls, node):
+            loaded_morphology = arraymorph.ArrayMorphology()
+            loaded_morphology.physical_mask = node.physical_mask[:]
+            loaded_morphology.vertices = node.vertices[:]
+            loaded_morphology.connectivity = node.connectivity[:]
+
+            return loaded_morphology
+
+    @classmethod
+    def load(cls, filepath):
+        """
+        Right now this load method isn't done in a very nice way.
+        TODO: Complete refactoring.
+        """
+        import tables
+        file = tables.openFile(filepath,mode='r')
+
+        document = neuroml.NeuroMLDocument()
+
+        for node in file.root:
+            if hasattr(node,'vertices'):
+                loaded_morphology = cls.__extract_morphology(node)
+                document.morphology.append(loaded_morphology)
+            else:
+                for morphology in node:
+                    loaded_morphology = cls.__extract_morphology(morphology)
+                    document.morphology.append(loaded_morphology)
+                
+        return document
+            
+    
